#include <algorithm>
#include <iostream>
#include <cstring>
#include <vector>
#include <queue>
#include <list>
#include <set>
#include <map>

using namespace std;

const int MAXN = 1e5 + 22;

struct Point
{
    int x, y;
    int code;

    Point(){}
    Point(int x, int y)
    {
        this->x = x;
        this->y = y;
    }
};

struct SegmentTree
{
    int maxVal, lazy;

    int l, r;
    SegmentTree *L, *R;

    SegmentTree(){}
    SegmentTree(int l, int r)
    {
        this->l = l;
        this->r = r;

        this->L = nullptr;
        this->R = nullptr;

        maxVal = 0;
        lazy = 0;
    }

    void build()
    {
        if(l==r) return;

        L = new SegmentTree(l, (l+r)/2);
        R = new SegmentTree((l+r)/2+1, r);

        L->build();
        R->build();
    }

    void updateLazy()
    {
        maxVal += lazy;
        if(l!=r)
        {
            L->lazy += lazy;
            R->lazy += lazy;
        }

        lazy = 0;
    }

    void recalc()
    {
        maxVal = max(L->maxVal, R->maxVal);
    }

    void update(int ql, int qr, int change)
    {
        updateLazy();

        if(l>=ql && r<=qr)
        {
            maxVal += change;
            if(l!=r)
            {
                L->lazy += change;
                R->lazy += change;
            }

            return;
        }
        if(r<ql || l>qr) return;

        L->update(ql, qr, change);
        R->update(ql, qr, change);
        recalc();
    }

    void setValue(int q, int value)
    {
        updateLazy();

        if(q==l && l==r)
        {
            maxVal = value;
            return;
        }
        if(q<l || q>r) return;

        L->setValue(q, value);
        R->setValue(q, value);
        recalc();
    }

    void optmimizeValue(int q, int value)
    {
        updateLazy();

        if(q==l && l==r)
        {
            maxVal = max(maxVal, value);
            return;
        }
        if(q<l || q>r) return;

        L->optmimizeValue(q, value);
        R->optmimizeValue(q, value);
        recalc();
    }
};

struct FenwickTree
{
    int n;
    int tree[MAXN];

    FenwickTree(){}
    FenwickTree(int n)
    {
        this->n = n + 2;
        memset(tree, 0, sizeof(tree));
    }

    void update(int ind, int change)
    {
        ind++;
        while(ind<=n)
        {
            tree[ind] += change;
            ind += ind&(-ind);
        }
    }

    int query(int ind)
    {
        ind++;
        int sum = 0;

        while(ind>0)
        {
            sum += tree[ind];
            ind -= ind&(-ind);
        }

        return sum;
    }

    int query(int l, int r)
    {
        return query(r) - query(l-1);
    }
};

struct PointsKeeper
{
    int w, h;
    list <Point> active;

    SegmentTree *T;
    set <int> allX;
    int codeX[MAXN];
    int xCnt[MAXN];

    FenwickTree welko;

    PointsKeeper(){}
    PointsKeeper(int w, int h, vector <Point> &points)
    {
        this->w = w;
        this->h = h;

        this->initTrees(points);
    }

    void initTrees(vector <Point> &points)
    {
        for(Point p: points) allX.insert(p.x);

        int ind = 0;
        for(int x: allX) codeX[x] = ind, ind++;

        T = new SegmentTree(0, allX.size()-1);
        T->build();

        welko = FenwickTree(allX.size());
    }

    int getCount(Point p)
    {
        auto it = allX.lower_bound(p.x-w);

        if(it!=allX.end())
        {
            return welko.query(codeX[*it], codeX[p.x]);
        }

        return -69;
    }

    void updateRange(Point p, int change)
    {
        auto it = allX.upper_bound(p.x+w);

        if(it!=allX.begin())
        {
            it--;
            T->update(p.code, codeX[*it], change);
        }
    }

    void addPoint(Point P)
    {
        P.code = codeX[P.x];

        xCnt[P.x]++;
        active.push_back(P);
        welko.update(P.code, +1);

        while((*active.begin()).y<P.y-h) removePoint();
        updateRange(P, +1);

        int cnt = getCount(P);
        T->setValue(P.code, cnt);
    }

    void removePoint()
    {
        Point P = *active.begin();

        xCnt[P.x]--;
        welko.update(P.code, -1);
        active.erase(active.begin());

        if(xCnt[P.x]==0) T->setValue(P.code, -MAXN*22);
        updateRange(P, -1);
    }

    int evalBest()
    {
        return T->maxVal;
    }
};

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    int n;
    int w, h;
    vector <Point> points;

    cin >> n;
    cin >> w >> h;
    for(int i = 0;i<n;i++)
    {
        int x, y;
        cin >> x >> y;

        points.push_back(Point(x, y));
    }

    sort(points.begin(), points.end(),
    [](Point A, Point  B)
    {
        if(A.y!=B.y) return A.y<B.y;
        return A.x<B.x;
    });

    int ans = 0;
    PointsKeeper yoanko(w, h, points);

    for(Point p: points)
    {
        yoanko.addPoint(p);
        ans = max(ans, yoanko.evalBest());
    }

    cout << ans << '\n';
}
